diff --git a/openbis/source/java/ch/systemsx/cisd/openbis/generic/client/web/client/ICommonClientServiceAsync.java b/openbis/source/java/ch/systemsx/cisd/openbis/generic/client/web/client/ICommonClientServiceAsync.java
index 9df8de28e2a70739e326f0d174777e8363330254..164843a659ac3300ea962fff3551e1b3cabc9a55 100644
--- a/openbis/source/java/ch/systemsx/cisd/openbis/generic/client/web/client/ICommonClientServiceAsync.java
+++ b/openbis/source/java/ch/systemsx/cisd/openbis/generic/client/web/client/ICommonClientServiceAsync.java
@@ -124,8 +124,8 @@ public interface ICommonClientServiceAsync extends IClientServiceAsync
     /** @see ICommonClientService#keepSessionAlive() */
     public void keepSessionAlive(final AsyncCallback<Boolean> asyncCallback);
 
-    /** @see ICommonClientService#listGroups(DefaultResultSetConfig) */
-    public void listGroups(DefaultResultSetConfig<String, TableModelRowWithObject<Space>> criteria,
+    /** @see ICommonClientService#listSpaces(DefaultResultSetConfig) */
+    public void listSpaces(DefaultResultSetConfig<String, TableModelRowWithObject<Space>> criteria,
             final AsyncCallback<TypedTableResultSet<Space>> asyncCallback);
 
     /** @see ICommonClientService#listScripts(ListScriptsCriteria) */
@@ -137,13 +137,13 @@ public interface ICommonClientServiceAsync extends IClientServiceAsync
             TableExportCriteria<TableModelRowWithObject<Script>> exportCriteria,
             AsyncCallback<String> callback);
 
-    /** @see ICommonClientService#prepareExportGroups(TableExportCriteria) */
-    public void prepareExportGroups(
+    /** @see ICommonClientService#prepareExportSpaces(TableExportCriteria) */
+    public void prepareExportSpaces(
             TableExportCriteria<TableModelRowWithObject<Space>> exportCriteria,
             AsyncCallback<String> callback);
 
-    /** @see ICommonClientService#registerGroup(String, String) */
-    public void registerGroup(String groupCode, String descriptionOrNull,
+    /** @see ICommonClientService#registerSpace(String, String) */
+    public void registerSpace(String spaceCode, String descriptionOrNull,
             AsyncCallback<Void> callback);
 
     /** @see ICommonClientService#registerScript(Script) */
@@ -152,8 +152,8 @@ public interface ICommonClientServiceAsync extends IClientServiceAsync
     /** @see ICommonClientService#updateScript(IScriptUpdates) */
     public void updateScript(final IScriptUpdates updates, final AsyncCallback<Void> asyncCallback);
 
-    /** @see ICommonClientService#updateGroup(ISpaceUpdates) */
-    public void updateGroup(final ISpaceUpdates updates, final AsyncCallback<Void> asyncCallback);
+    /** @see ICommonClientService#updateSpace(ISpaceUpdates) */
+    public void updateSpace(final ISpaceUpdates updates, final AsyncCallback<Void> asyncCallback);
 
     /** @see ICommonClientService#listPersons(ListPersonsCriteria) */
     public void listPersons(ListPersonsCriteria criteria,
@@ -177,12 +177,12 @@ public interface ICommonClientServiceAsync extends IClientServiceAsync
             TableExportCriteria<TableModelRowWithObject<RoleAssignment>> exportCriteria,
             AsyncCallback<String> callback);
 
-    /** @see ICommonClientService#registerGroupRole(RoleWithHierarchy, String, Grantee) */
-    public void registerGroupRole(RoleWithHierarchy role, String group, Grantee grantee,
+    /** @see ICommonClientService#registerSpaceRole(RoleWithHierarchy, String, Grantee) */
+    public void registerSpaceRole(RoleWithHierarchy role, String spaceCode, Grantee grantee,
             AsyncCallback<Void> asyncCallback);
 
-    /** @see ICommonClientService#deleteGroupRole(RoleWithHierarchy, String, Grantee) */
-    public void deleteGroupRole(RoleWithHierarchy role, String group, Grantee grantee,
+    /** @see ICommonClientService#deleteSpaceRole(RoleWithHierarchy, String, Grantee) */
+    public void deleteSpaceRole(RoleWithHierarchy role, String spaceCode, Grantee grantee,
             AsyncCallback<Void> asyncCallback);
 
     /** @see ICommonClientService#registerInstanceRole(RoleWithHierarchy, Grantee) */
@@ -607,8 +607,8 @@ public interface ICommonClientServiceAsync extends IClientServiceAsync
     public void deleteProjects(List<TechId> projectIds, String reason,
             AsyncCallback<Void> asyncCallback);
 
-    /** @see ICommonClientService#deleteGroups(List, String) */
-    public void deleteGroups(List<TechId> groupIds, String reason, AsyncCallback<Void> asyncCallback);
+    /** @see ICommonClientService#deleteSpaces(List, String) */
+    public void deleteSpaces(List<TechId> spaceIds, String reason, AsyncCallback<Void> asyncCallback);
 
     /** @see ICommonClientService#deleteScripts(List) */
     public void deleteScripts(List<TechId> scriptIds, AsyncCallback<Void> asyncCallback);
diff --git a/openbis/source/java/ch/systemsx/cisd/openbis/generic/client/web/client/application/Dict.java b/openbis/source/java/ch/systemsx/cisd/openbis/generic/client/web/client/application/Dict.java
index cf67253ddf7aba7cd6d5ebfbfcc2bd5eb7350e11..6abbad89508b18d1c0bc15792138f4be64c177c2 100644
--- a/openbis/source/java/ch/systemsx/cisd/openbis/generic/client/web/client/application/Dict.java
+++ b/openbis/source/java/ch/systemsx/cisd/openbis/generic/client/web/client/application/Dict.java
@@ -29,7 +29,7 @@ package ch.systemsx.cisd.openbis.generic.client.web.client.application;
 public abstract class Dict
 {
 
-    public static final String ADD_GROUP_TITLE = "add_group_title";
+    public static final String ADD_SPACE_TITLE = "add_space_title";
 
     public static final String ADD_SCRIPT_TITLE = "add_script_title";
 
@@ -879,9 +879,9 @@ public abstract class Dict
             "make_official_vocabulary_terms_confirmation_message";
 
     //
-    // Group Browser
+    // Space Browser
     //
-    public static final String GROUP_BROWSER = "group_browser";
+    public static final String SPACE_BROWSER = "space_browser";
 
     //
     // Person Browser
diff --git a/openbis/source/java/ch/systemsx/cisd/openbis/generic/client/web/client/application/framework/ComponentProvider.java b/openbis/source/java/ch/systemsx/cisd/openbis/generic/client/web/client/application/framework/ComponentProvider.java
index 91c402b659ccfbe7843eeb75e840c11dd0c07a37..413a3057c4526363213d149dd695ccb7c67224dc 100644
--- a/openbis/source/java/ch/systemsx/cisd/openbis/generic/client/web/client/application/framework/ComponentProvider.java
+++ b/openbis/source/java/ch/systemsx/cisd/openbis/generic/client/web/client/application/framework/ComponentProvider.java
@@ -231,7 +231,7 @@ public final class ComponentProvider
                 @Override
                 public String getTabTitle()
                 {
-                    return getMessage(Dict.GROUP_BROWSER);
+                    return getMessage(Dict.SPACE_BROWSER);
                 }
 
                 @Override
diff --git a/openbis/source/java/ch/systemsx/cisd/openbis/generic/client/web/client/application/ui/RoleAssignmentGrid.java b/openbis/source/java/ch/systemsx/cisd/openbis/generic/client/web/client/application/ui/RoleAssignmentGrid.java
index 12ee4b8e3b0464de2a2f6faee16e2ef3792df14a..36fc7db10be8d83459820885a7cdc128d621cf81 100644
--- a/openbis/source/java/ch/systemsx/cisd/openbis/generic/client/web/client/application/ui/RoleAssignmentGrid.java
+++ b/openbis/source/java/ch/systemsx/cisd/openbis/generic/client/web/client/application/ui/RoleAssignmentGrid.java
@@ -150,7 +150,7 @@ public class RoleAssignmentGrid extends TypedTableGrid<RoleAssignment>
                         selectedRoleAssignment.getRoleSetCode(), grantee, roleListRefreshCallback);
             } else
             {
-                viewContext.getService().deleteGroupRole(selectedRoleAssignment.getRoleSetCode(),
+                viewContext.getService().deleteSpaceRole(selectedRoleAssignment.getRoleSetCode(),
                         selectedRoleAssignment.getSpace().getCode(), grantee,
                         roleListRefreshCallback);
             }
diff --git a/openbis/source/java/ch/systemsx/cisd/openbis/generic/client/web/client/application/ui/SpaceGrid.java b/openbis/source/java/ch/systemsx/cisd/openbis/generic/client/web/client/application/ui/SpaceGrid.java
index daaab4ffe71096cb094c874525cca8e40f891276..2087165601219a083e0ea0b74746f2cd32622061 100644
--- a/openbis/source/java/ch/systemsx/cisd/openbis/generic/client/web/client/application/ui/SpaceGrid.java
+++ b/openbis/source/java/ch/systemsx/cisd/openbis/generic/client/web/client/application/ui/SpaceGrid.java
@@ -166,7 +166,7 @@ public class SpaceGrid extends TypedTableGrid<Space>
                 {
                     space.setDescription(descriptionField.getValue());
 
-                    viewContext.getService().updateGroup(space, registrationCallback);
+                    viewContext.getService().updateSpace(space, registrationCallback);
                 }
             };
     }
@@ -192,7 +192,7 @@ public class SpaceGrid extends TypedTableGrid<Space>
             DefaultResultSetConfig<String, TableModelRowWithObject<Space>> resultSetConfig,
             AbstractAsyncCallback<TypedTableResultSet<Space>> callback)
     {
-        viewContext.getService().listGroups(resultSetConfig, callback);
+        viewContext.getService().listSpaces(resultSetConfig, callback);
     }
 
     @Override
@@ -200,7 +200,7 @@ public class SpaceGrid extends TypedTableGrid<Space>
             TableExportCriteria<TableModelRowWithObject<Space>> exportCriteria,
             AbstractAsyncCallback<String> callback)
     {
-        viewContext.getService().prepareExportGroups(exportCriteria, callback);
+        viewContext.getService().prepareExportSpaces(exportCriteria, callback);
     }
 
     @Override
@@ -235,7 +235,7 @@ public class SpaceGrid extends TypedTableGrid<Space>
             {
                 list.add(new TechId(tableModelRowWithObject.getObjectOrNull().getId()));
             }
-            viewContext.getCommonService().deleteGroups(list, reason.getValue(), deletionCallback);
+            viewContext.getCommonService().deleteSpaces(list, reason.getValue(), deletionCallback);
         }
 
         @Override
diff --git a/openbis/source/java/ch/systemsx/cisd/openbis/generic/client/web/client/application/ui/SpaceSelectionWidget.java b/openbis/source/java/ch/systemsx/cisd/openbis/generic/client/web/client/application/ui/SpaceSelectionWidget.java
index 85156baf89bb31e8558a18f6ffdb892e810b8e22..9ddf2a80b16cc06e48485d295f511031b8ce38fa 100644
--- a/openbis/source/java/ch/systemsx/cisd/openbis/generic/client/web/client/application/ui/SpaceSelectionWidget.java
+++ b/openbis/source/java/ch/systemsx/cisd/openbis/generic/client/web/client/application/ui/SpaceSelectionWidget.java
@@ -224,7 +224,7 @@ public class SpaceSelectionWidget extends DropDownList<SpaceModel, Space>
     {
         DefaultResultSetConfig<String, TableModelRowWithObject<Space>> config =
                 DefaultResultSetConfig.createFetchAll();
-        viewContext.getCommonService().listGroups(config, new ListSpaceCallback(viewContext));
+        viewContext.getCommonService().listSpaces(config, new ListSpaceCallback(viewContext));
         callback.ignore();
     }
 
diff --git a/openbis/source/java/ch/systemsx/cisd/openbis/generic/client/web/client/application/ui/amc/AddGroupDialog.java b/openbis/source/java/ch/systemsx/cisd/openbis/generic/client/web/client/application/ui/amc/AddGroupDialog.java
index 731213a6e1449b3ba85faf2acf9d4e1f2b0bfe69..cd1b3aa8b81f257fabae84c1e524d27d2dc45dfe 100644
--- a/openbis/source/java/ch/systemsx/cisd/openbis/generic/client/web/client/application/ui/amc/AddGroupDialog.java
+++ b/openbis/source/java/ch/systemsx/cisd/openbis/generic/client/web/client/application/ui/amc/AddGroupDialog.java
@@ -44,7 +44,7 @@ public class AddGroupDialog extends AbstractRegistrationDialog
     public AddGroupDialog(final IViewContext<ICommonClientServiceAsync> viewContext,
             final IDelegatedAction postRegistrationCallback)
     {
-        super(viewContext, viewContext.getMessage(Dict.ADD_GROUP_TITLE), postRegistrationCallback);
+        super(viewContext, viewContext.getMessage(Dict.ADD_SPACE_TITLE), postRegistrationCallback);
         this.viewContext = viewContext;
         this.codeField = createCodeField(viewContext);
         addField(codeField);
@@ -56,7 +56,7 @@ public class AddGroupDialog extends AbstractRegistrationDialog
     @Override
     protected void register(AsyncCallback<Void> registrationCallback)
     {
-        viewContext.getService().registerGroup(codeField.getValue(), descriptionField.getValue(),
+        viewContext.getService().registerSpace(codeField.getValue(), descriptionField.getValue(),
                 registrationCallback);
     }
 }
diff --git a/openbis/source/java/ch/systemsx/cisd/openbis/generic/client/web/client/application/ui/amc/AddRoleAssignmentDialog.java b/openbis/source/java/ch/systemsx/cisd/openbis/generic/client/web/client/application/ui/amc/AddRoleAssignmentDialog.java
index 750d23cc08e8eb0909182acd4cca5268750eaf59..4333021acae1134b833ee895ee941f20329f9c96 100644
--- a/openbis/source/java/ch/systemsx/cisd/openbis/generic/client/web/client/application/ui/amc/AddRoleAssignmentDialog.java
+++ b/openbis/source/java/ch/systemsx/cisd/openbis/generic/client/web/client/application/ui/amc/AddRoleAssignmentDialog.java
@@ -138,7 +138,7 @@ public class AddRoleAssignmentDialog extends AbstractRegistrationDialog
         } else
         {
             Space spaceOrNull = group.tryGetSelectedSpace();
-            viewContext.getService().registerGroupRole(
+            viewContext.getService().registerSpaceRole(
                     ((RoleListBox) roleBox.getWidget()).getValue(), spaceOrNull.getCode(), grantee,
                     registrationCallback);
         }
diff --git a/openbis/source/java/ch/systemsx/cisd/openbis/generic/client/web/server/CommonClientService.java b/openbis/source/java/ch/systemsx/cisd/openbis/generic/client/web/server/CommonClientService.java
index 1f5bc1e53abc238593a73f67a2296ff03d43f773..b939fe0a5ca0317549a3f4bd2b45e29977d7221b 100644
--- a/openbis/source/java/ch/systemsx/cisd/openbis/generic/client/web/server/CommonClientService.java
+++ b/openbis/source/java/ch/systemsx/cisd/openbis/generic/client/web/server/CommonClientService.java
@@ -310,14 +310,14 @@ public final class CommonClientService extends AbstractClientService implements
     //
 
     @Override
-    public final void registerGroup(final String groupCode, final String descriptionOrNull)
+    public final void registerSpace(final String groupCode, final String descriptionOrNull)
     {
         final String sessionToken = getSessionToken();
         commonServer.registerSpace(sessionToken, groupCode, descriptionOrNull);
     }
 
     @Override
-    public final void updateGroup(final ISpaceUpdates updates)
+    public final void updateSpace(final ISpaceUpdates updates)
     {
         assert updates != null : "Unspecified updates.";
 
@@ -342,7 +342,7 @@ public final class CommonClientService extends AbstractClientService implements
     }
 
     @Override
-    public final void registerGroupRole(final RoleWithHierarchy role, final String group,
+    public final void registerSpaceRole(final RoleWithHierarchy role, final String group,
             final Grantee grantee)
     {
         final String sessionToken = getSessionToken();
@@ -359,7 +359,7 @@ public final class CommonClientService extends AbstractClientService implements
     }
 
     @Override
-    public final void deleteGroupRole(final RoleWithHierarchy role, final String group,
+    public final void deleteSpaceRole(final RoleWithHierarchy role, final String group,
             final Grantee grantee)
     {
         final String sessionToken = getSessionToken();
@@ -503,7 +503,7 @@ public final class CommonClientService extends AbstractClientService implements
     }
 
     @Override
-    public String prepareExportGroups(TableExportCriteria<TableModelRowWithObject<Space>> criteria)
+    public String prepareExportSpaces(TableExportCriteria<TableModelRowWithObject<Space>> criteria)
     {
         return prepareExportEntities(criteria);
     }
@@ -638,7 +638,7 @@ public final class CommonClientService extends AbstractClientService implements
     }
 
     @Override
-    public TypedTableResultSet<Space> listGroups(
+    public TypedTableResultSet<Space> listSpaces(
             DefaultResultSetConfig<String, TableModelRowWithObject<Space>> criteria)
     {
         SpacesProvider spacesProvider = new SpacesProvider(commonServer, getSessionToken());
@@ -1499,7 +1499,7 @@ public final class CommonClientService extends AbstractClientService implements
     }
 
     @Override
-    public void deleteGroups(List<TechId> groupIds, String reason)
+    public void deleteSpaces(List<TechId> groupIds, String reason)
             throws ch.systemsx.cisd.openbis.generic.client.web.client.exception.UserFailureException
     {
         final String sessionToken = getSessionToken();
diff --git a/openbis/source/java/ch/systemsx/cisd/openbis/public/common-dictionary.js b/openbis/source/java/ch/systemsx/cisd/openbis/public/common-dictionary.js
index 74acd04f5eb8d2fc340cb870e8c8afdc9068be6e..c0eccb691bcce757d85da0169f9b4409e81e8af7 100644
--- a/openbis/source/java/ch/systemsx/cisd/openbis/public/common-dictionary.js
+++ b/openbis/source/java/ch/systemsx/cisd/openbis/public/common-dictionary.js
@@ -685,9 +685,9 @@ var common = {
  //
  // Space Browser
  //
- group_browser: "Space Browser",
+ space_browser: "Space Browser",
  leader: "Head",
- add_group_title: "Add a new space",
+ add_space_title: "Add a new space",
 
  //
  // Project Browser
diff --git a/openbis/source/java/ch/systemsx/cisd/openbis/generic/client/web/client/ICommonClientService.java b/openbis/source/java/ch/systemsx/cisd/openbis/generic/client/web/client/ICommonClientService.java
index 6c299eb16afa8a9619500bb459f0a230469991d6..237b4f06d5933b0feb8254d608f182f2b52026ac 100644
--- a/openbis/source/java/ch/systemsx/cisd/openbis/generic/client/web/client/ICommonClientService.java
+++ b/openbis/source/java/ch/systemsx/cisd/openbis/generic/client/web/client/ICommonClientService.java
@@ -132,9 +132,9 @@ public interface ICommonClientService extends IClientService
     public Boolean keepSessionAlive() throws UserFailureException;
 
     /**
      * Returns a list of all groups.
      */
-    public TypedTableResultSet<Space> listGroups(
+    public TypedTableResultSet<Space> listSpaces(
             DefaultResultSetConfig<String, TableModelRowWithObject<Space>> criteria)
             throws UserFailureException;
 
@@ -152,16 +152,16 @@ public interface ICommonClientService extends IClientService
             throws UserFailureException;
 
     /**
      * Like {@link #prepareExportSamples(TableExportCriteria)}, but for groups.
      */
-    public String prepareExportGroups(
+    public String prepareExportSpaces(
             final TableExportCriteria<TableModelRowWithObject<Space>> criteria)
             throws UserFailureException;
 
     /**
-     * Registers a new group with specified code and optional description.
+     * Registers a new space with specified code and optional description.
      */
-    public void registerGroup(String groupCode, String descriptionOrNull)
+    public void registerSpace(String spaceCode, String descriptionOrNull)
             throws UserFailureException;
 
     /**
@@ -170,9 +170,9 @@ public interface ICommonClientService extends IClientService
     public void updateScript(final IScriptUpdates updates) throws UserFailureException;
 
     /**
-     * Updates group.
+     * Updates space.
      */
-    public void updateGroup(final ISpaceUpdates updates) throws UserFailureException;
+    public void updateSpace(final ISpaceUpdates updates) throws UserFailureException;
 
     /**
      * Returns a list of all persons which belong to the current database instance.
@@ -217,15 +217,15 @@ public interface ICommonClientService extends IClientService
             throws UserFailureException;
 
     /**
-     * Registers a new role from given role set code, group code and grantee.
+     * Registers a new role from given role set code, space code and grantee.
      */
-    public void registerGroupRole(RoleWithHierarchy role, String group, Grantee grantee)
+    public void registerSpaceRole(RoleWithHierarchy role, String spaceCode, Grantee grantee)
             throws UserFailureException;
 
     /**
-     * Deletes the role described by given role set code, group code and grantee.
+     * Deletes the role described by given role set code, space code and grantee.
      */
-    public void deleteGroupRole(RoleWithHierarchy role, String group, Grantee grantee)
+    public void deleteSpaceRole(RoleWithHierarchy role, String spaceCode, Grantee grantee)
             throws UserFailureException;
 
     /**
@@ -698,8 +698,8 @@ public interface ICommonClientService extends IClientService
     /** Deletes the specified projects. */
     public void deleteProjects(List<TechId> projectIds, String reason) throws UserFailureException;
 
-    /** Deletes the specified groups. */
-    public void deleteGroups(List<TechId> groupIds, String reason) throws UserFailureException;
+    /** Deletes the specified spaces. */
+    public void deleteSpaces(List<TechId> spaceIds, String reason) throws UserFailureException;
 
     /** Deletes the specified scripts. */
     public void deleteScripts(List<TechId> scriptIds) throws UserFailureException;
@@ -132,9 +132,9 @@ public interface ICommonClientService extends IClientService
 
     /**
-     * Returns a list of all groups.
+     * Returns a list of all spaces.
      */
@@ -152,16 +152,16 @@ public interface ICommonClientService extends IClientService
 
     /**
-     * Like {@link #prepareExportSamples(TableExportCriteria)}, but for groups.
+     * Like {@link #prepareExportSamples(TableExportCriteria)}, but for spaces.
      */
diff --git a/openbis/source/java/ch/systemsx/cisd/openbis/generic/client/web/client/application/ui/AddGroupDialog.java b/openbis/source/java/ch/systemsx/cisd/openbis/generic/client/web/client/application/ui/AddSpaceDialog.java
similarity index 87%
rename from openbis/source/java/ch/systemsx/cisd/openbis/generic/client/web/client/application/ui/AddGroupDialog.java
rename to openbis/source/java/ch/systemsx/cisd/openbis/generic/client/web/client/application/ui/AddSpaceDialog.java
index fb78a6a39785f9a6bb24561e91dbbdeac2b0eeab..89f47cd3f5dd18fa0f2f904a557d58496536745f 100644
--- a/openbis/source/java/ch/systemsx/cisd/openbis/generic/client/web/client/application/ui/AddGroupDialog.java
+++ b/openbis/source/java/ch/systemsx/cisd/openbis/generic/client/web/client/application/ui/AddSpaceDialog.java
@@ -28,12 +28,12 @@ import ch.systemsx.cisd.openbis.generic.client.web.client.application.ui.widget.
 import ch.systemsx.cisd.openbis.generic.client.web.client.application.util.IDelegatedAction;
 
 /**
  * {@link Window} containing group registration form.
  * 
  * @author Franz-Josef Elmer
  * @author Izabela Adamczyk
  */
-public class AddGroupDialog extends AbstractRegistrationDialog
+public class AddSpaceDialog extends AbstractRegistrationDialog
 {
     private final IViewContext<ICommonClientServiceAsync> viewContext;
 
@@ -41,10 +41,10 @@ public class AddGroupDialog extends AbstractRegistrationDialog
 
     private final DescriptionField descriptionField;
 
-    public AddGroupDialog(final IViewContext<ICommonClientServiceAsync> viewContext,
+    public AddSpaceDialog(final IViewContext<ICommonClientServiceAsync> viewContext,
             final IDelegatedAction postRegistrationCallback)
     {
-        super(viewContext, viewContext.getMessage(Dict.ADD_GROUP_TITLE),
+        super(viewContext, viewContext.getMessage(Dict.ADD_SPACE_TITLE),
                 postRegistrationCallback);
         this.viewContext = viewContext;
         this.codeField = createCodeField(viewContext);
@@ -57,7 +57,7 @@ public class AddGroupDialog extends AbstractRegistrationDialog
     @Override
     protected void register(AsyncCallback<Void> registrationCallback)
     {
-        viewContext.getService().registerGroup(codeField.getValue(), descriptionField.getValue(),
+        viewContext.getService().registerSpace(codeField.getValue(), descriptionField.getValue(),
                 registrationCallback);
     }
 }
@@ -28,12 +28,12 @@ import ch.systemsx.cisd.openbis.generic.client.web.client.application.ui.widget.
 
 /**
- * {@link Window} containing group registration form.
+ * {@link Window} containing space registration form.
  * 
  * @author Franz-Josef Elmer